@@ -1,9 +1,9 @@
 import OpenGL
 OpenGL.USE_ACCELERATE = True
 from OpenGL.GL import *
-import texture
-import screen_rect
-import shader_utils
+from pygame_shaders import texture
+from pygame_shaders import screen_rect
+from pygame_shaders import shader_utils
 
 def clear(color):
     glClearColor(color[0]/255, color[1]/255, color[2]/255, 1)
